==> dojo_1.15.4+dfsg1.orig.tar.xz: dojo-release-1.15.4-src/dojo/cldr/nls/ja/chinese.js <==
define(
//begin v1.x content
{
	"field-tue-relative+-1": "先週の火曜日",
	"field-year": "年",
	"dateFormatItem-MEEEEd": "M/dEEEE",
	"dateFormatItem-Hm": "H:mm",
	"field-wed-relative+0": "今週の水曜日",
	"field-wed-relative+1": "来週の水曜日",
	"field-minute": "分",
	"field-month-narrow-relative+-1": "先月",
	"field-tue-narrow-relative+0": "今週の火曜",
	"field-tue-narrow-relative+1": "来週の火曜",
	"field-day-short-relative+-1": "昨日",
	"field-thu-short-relative+0": "今週の木曜",
	"field-day-relative+0": "今日",
	"field-day-short-relative+-2": "一昨日",
	"field-thu-short-relative+1": "来週の木曜",
	"field-day-relative+1": "明日",
	"field-week-narrow-relative+0": "今週",
	"field-day-relative+2": "明後日",
	"field-week-narrow-relative+1": "翌週",
	"field-wed-narrow-relative+-1": "先週の水曜",
	"field-year-narrow": "年",
	"field-year-narrow-relative+0": "今年",
	"field-tue-relative+0": "今週の火曜日",
	"field-year-narrow-relative+1": "翌年",
	"field-tue-relative+1": "来週の火曜日",
	"field-second-short": "秒",
	"dateFormatItem-MMMd": "MMMd日",
	"field-week-relative+0": "今週",
	"field-month-relative+0": "今月",
	"field-week-relative+1": "翌週",
	"field-month-relative+1": "翌月",
	"field-sun-narrow-relative+0": "今週の日曜",
	"field-mon-short-relative+0": "今週の月曜",
	"field-sun-narrow-relative+1": "来週の日曜",
	"field-mon-short-relative+1": "来週の月曜",
	"field-second-relative+0": "今",
	"dateFormatItem-yyyyQQQ": "U年QQQ",
	"months-standAlone-narrow": [
		"正",
		"二",
		"三",
		"四",
		"五",
		"六",
		"七",
		"八",
		"九",
		"十",
		"十一",
		"十二"
	],
	"field-month-short": "月",
	"dateFormatItem-GyMMMEd": "U年MMMd日(E)",
	"dateFormatItem-yyyyMd": "U年M月d日",
	"field-day": "日",
	"field-year-relative+-1": "昨年",
	"field-sat-short-relative+-1": "先週の土曜",
	"field-hour-relative+0": "1 時間以内",
	"dateFormatItem-yyyyMEd": "U年M月d日(E)",
	"field-wed-relative+-1": "先週の水曜日",
	"field-sat-narrow-relative+-1": "先週の土曜",
	"field-second": "秒",
	"dateFormat-long": "U年MMMd日",
	"dateFormatItem-GyMMMd": "U年MMMd日",
	"field-quarter": "四半期",
	"field-week-short": "週",
	"field-day-narrow-relative+0": "今日",
	"field-day-narrow-relative+1": "明日",
	"field-day-narrow-relative+2": "明後日",
	"dateFormatItem-MMMEEEEd": "MMMd日EEEE",
	"field-tue-short-relative+0": "今週の火曜",
	"field-tue-short-relative+1": "来週の火曜",
	"field-month-short-relative+-1": "先月",
	"field-mon-relative+-1": "先週の月曜日",
	"dateFormatItem-GyMMM": "U年MMM",
	"field-month": "月",
	"field-day-narrow": "日",
	"field-minute-short": "分",
	"field-dayperiod": "午前/午後",
	"field-sat-short-relative+0": "今週の土曜",
	"field-sat-short-relative+1": "来週の土曜",
	"dateFormat-medium": "U年MMMd日",
	"dateFormatItem-yyyyMMMM": "U年MMMM",
	"dateFormatItem-EEEEd": "d日EEEE",
	"dateFormatItem-yyyyM": "U年M月",
	"field-second-narrow": "秒",
	"field-mon-relative+0": "今週の月曜日",
	"field-mon-relative+1": "来週の月曜日",
	"field-day-narrow-relative+-1": "昨日",
	"field-year-short": "年",
	"field-day-narrow-relative+-2": "一昨日",
	"months-format-narrow": [
		"正",
		"二",
		"三",
		"四",
		"五",
		"六",
		"七",
		"八",
		"九",
		"十",
		"十一",
		"十二"
	],
	"field-quarter-relative+-1": "前四半期",
	"dateFormatItem-yyyyMMMd": "U年MMMd日",
	"field-week-narrow-relative+-1": "先週",
	"field-sat-relative+-1": "先週の土曜日",
	"dateFormatItem-Md": "M/d",
	"field-hour": "時",
	"months-format-wide": [
		"正月",
		"二月",
		"三月",
		"四月",
		"五月",
		"六月",
		"七月",
		"八月",
		"九月",
		"十月",
		"十一月",
		"十二月"
	],
	"dateFormat-full": "U年MMMd日EEEE",
	"field-month-relative+-1": "先月",
	"dateFormatItem-Hms": "H:mm:ss",
	"field-quarter-short": "四半期",
	"field-sat-narrow-relative+0": "今週の土曜",
	"field-fri-relative+0": "今週の金曜日",
	"field-sat-narrow-relative+1": "来週の土曜",
	"field-fri-relative+1": "来週の金曜日",
	"field-month-narrow-relative+0": "今月",
	"field-month-narrow-relative+1": "翌月",
	"field-sun-short-relative+0": "今週の日曜",
	"field-sun-short-relative+1": "来週の日曜",
	"field-week-relative+-1": "先週",
	"months-format-abbr": [
		"正月",
		"二月",
		"三月",
		"四月",
		"五月",
		"六月",
		"七月",
		"八月",
		"九月",
		"十月",
		"十一月",
		"十二月"
	],
	"field-quarter-relative+0": "今四半期",
	"field-minute-relative+0": "1 分以内",
	"field-quarter-relative+1": "翌四半期",
	"field-wed-short-relative+-1": "先週の水曜",
	"dateFormat-short": "U-M-d",
	"field-year-narrow-relative+-1": "昨年",
	"field-thu-short-relative+-1": "先週の木曜",
	"dateFormatItem-yyyyMMMEd": "U年MMMd日(E)",
	"field-mon-narrow-relative+-1": "先週の月曜",
	"dateFormatItem-MMMMd": "MMMMd日",
	"field-thu-narrow-relative+-1": "先週の木曜",
	"field-tue-narrow-relative+-1": "先週の火曜",
	"dateFormatItem-H": "H時",
	"dateFormatItem-yyyy": "U年",
	"field-wed-short-relative+0": "今週の水曜",
	"dateFormatItem-M": "MMM",
	"months-standAlone-wide": [
		"正月",
		"二月",
		"三月",
		"四月",
		"五月",
		"六月",
		"七月",
		"八月",
		"九月",
		"十月",
		"十一月",
		"十二月"
	],
	"field-wed-short-relative+1": "来週の水曜",
	"field-sun-relative+-1": "先週の日曜日",
	"dateFormatItem-hm": "aK:mm",
	"dateFormatItem-d": "d日",
	"field-weekday": "曜日",
	"field-day-short-relative+0": "今日",
	"field-day-short-relative+1": "明日",
	"field-sat-relative+0": "今週の土曜日",
	"dateFormatItem-h": "aK時",
	"dateFormatItem-yyyyMEEEEd": "U年M月d日EEEE",
	"field-day-short-relative+2": "明後日",
	"field-sat-relative+1": "来週の土曜日",
	"field-week-short-relative+0": "今週",
	"field-week-short-relative+1": "翌週",
	"months-standAlone-abbr": [
		"正月",
		"二月",
		"三月",
		"四月",
		"五月",
		"六月",
		"七月",
		"八月",
		"九月",
		"十月",
		"十一月",
		"十二月"
	],
	"field-month-short-relative+0": "今月",
	"field-month-short-relative+1": "翌月",
	"dateFormatItem-MEd": "M/d(E)",
	"dateFormatItem-y": "U年",
	"field-thu-narrow-relative+0": "今週の木曜",
	"field-sun-narrow-relative+-1": "先週の日曜",
	"field-mon-short-relative+-1": "先週の月曜",
	"field-thu-narrow-relative+1": "来週の木曜",
	"field-thu-relative+0": "今週の木曜日",
	"field-thu-relative+1": "来週の木曜日",
	"dateFormatItem-hms": "aK:mm:ss",
	"field-fri-short-relative+-1": "先週の金曜",
	"field-thu-relative+-1": "先週の木曜日",
	"dateFormatItem-yMd": "U年M月d日",
	"field-week": "週",
	"dateFormatItem-Ed": "d日(E)",
	"field-wed-narrow-relative+0": "今週の水曜",
	"field-wed-narrow-relative+1": "来週の水曜",
	"dateFormatItem-yyyyMMMEEEEd": "U年MMMd日EEEE",
	"field-year-short-relative+0": "今年",
	"dateFormatItem-yyyyMMM": "U年MMM",
	"field-year-short-relative+1": "翌年",
	"field-fri-short-relative+0": "今週の金曜",
	"field-fri-short-relative+1": "来週の金曜",
	"field-week-short-relative+-1": "先週",
	"dateFormatItem-yyyyQQQQ": "U年QQQQ",
	"field-hour-short": "時",
	"field-month-narrow": "月",
	"field-hour-narrow": "時",
	"field-fri-narrow-relative+-1": "先週の金曜",
	"field-year-relative+0": "今年",
	"field-year-relative+1": "翌年",
	"field-fri-relative+-1": "先週の金曜日",
	"field-tue-short-relative+-1": "先週の火曜",
	"field-minute-narrow": "分",
	"field-mon-narrow-relative+0": "今週の月曜",
	"field-mon-narrow-relative+1": "来週の月曜",
	"dateFormatItem-GyMMMEEEEd": "U年MMMd日EEEE",
	"field-year-short-relative+-1": "昨年",
	"field-zone": "タイムゾーン",
	"dateFormatItem-MMMEd": "MMMd日(E)",
	"field-quarter-narrow": "四半期",
	"field-sun-short-relative+-1": "先週の日曜",
	"field-day-relative+-1": "昨日",
	"field-day-relative+-2": "一昨日",
	"field-sun-relative+0": "今週の日曜日",
	"field-sun-relative+1": "来週の日曜日",
	"dateFormatItem-Gy": "U年",
	"field-day-short": "日",
	"field-week-narrow": "週",
	"field-era": "時代",
	"field-fri-narrow-relative+0": "今週の金曜",
	"field-fri-narrow-relative+1": "来週の金曜"
}
//end v1.x content
);

==> dojo_1.17.2+dfsg1.orig.tar.xz: dojo-release-1.17.2-src/dojo/cldr/nls/ja/chinese.js <==
define(
//begin v1.x content
{
	"field-quarter-short-relative+0": "今四半期",
	"field-quarter-short-relative+1": "翌四半期",
	"field-tue-relative+-1": "先週の火曜日",
	"field-year": "年",
	"dateFormatItem-MEEEEd": "M/dEEEE",
	"dateFormatItem-Hm": "H:mm",
	"field-wed-relative+0": "今週の水曜日",
	"field-wed-relative+1": "来週の水曜日",
	"dateFormatItem-ms": "mm:ss",
	"field-minute": "分",
	"field-month-narrow-relative+-1": "先月",
	"field-tue-narrow-relative+0": "今週の火曜",
	"field-tue-narrow-relative+1": "来週の火曜",
	"field-day-short-relative+-1": "昨日",
	"field-thu-short-relative+0": "今週の木曜",
	"field-day-relative+0": "今日",
	"field-day-short-relative+-2": "一昨日",
	"field-thu-short-relative+1": "来週の木曜",
	"field-day-relative+1": "明日",
	"field-week-narrow-relative+0": "今週",
	"field-day-relative+2": "明後日",
	"field-week-narrow-relative+1": "来週",
	"dateFormatItem-EBhms": "BK:mm:ss (E)",
	"field-wed-narrow-relative+-1": "先週の水曜",
	"field-year-narrow": "年",
	"field-era-short": "時代",
	"field-year-narrow-relative+0": "今年",
	"field-tue-relative+0": "今週の火曜日",
	"field-year-narrow-relative+1": "来年",
	"field-tue-relative+1": "来週の火曜日",
	"field-weekdayOfMonth": "月の曜日番号",
	"field-second-short": "秒",
	"dateFormatItem-MMMd": "MMMd日",
	"field-weekdayOfMonth-narrow": "月の曜日番号",
	"field-week-relative+0": "今週",
	"field-month-relative+0": "今月",
	"field-week-relative+1": "来週",
	"field-month-relative+1": "来月",
	"field-sun-narrow-relative+0": "今週の日曜",
	"field-mon-short-relative+0": "今週の月曜",
	"field-sun-narrow-relative+1": "来週の日曜",
	"field-mon-short-relative+1": "来週の月曜",
	"field-second-relative+0": "今",
	"dateFormatItem-yyyyQQQ": "U年QQQ",
	"months-standAlone-narrow": [
		"正",
		"二",
		"三",
		"四",
		"五",
		"六",
		"七",
		"八",
		"九",
		"十",
		"十一",
		"十二"
	],
	"field-weekOfMonth": "月の週番号",
	"field-month-short": "月",
	"dateFormatItem-GyMMMEd": "U年MMMd日(E)",
	"dateFormatItem-yyyyMd": "U年M月d日",
	"field-day": "日",
	"field-dayOfYear-short": "年の通日",
	"field-year-relative+-1": "昨年",
	"field-sat-short-relative+-1": "先週の土曜",
	"field-hour-relative+0": "1 時間以内",
	"dateFormatItem-yyyyMEd": "U年M月d日(E)",
	"field-wed-relative+-1": "先週の水曜日",
	"field-sat-narrow-relative+-1": "先週の土曜",
	"field-second": "秒",
	"dateFormat-long": "U年MMMd日",
	"dateFormatItem-GyMMMd": "U年MMMd日",
	"field-quarter": "四半期",
	"field-week-short": "週",
	"field-day-narrow-relative+0": "今日",
	"field-day-narrow-relative+1": "明日",
	"field-day-narrow-relative+2": "明後日",
	"dateFormatItem-MMMEEEEd": "MMMd日EEEE",
	"field-tue-short-relative+0": "今週の火曜",
	"field-tue-short-relative+1": "来週の火曜",
	"field-month-short-relative+-1": "先月",
	"field-mon-relative+-1": "先週の月曜日",
	"dateFormatItem-GyMMM": "U年MMM",
	"field-month": "月",
	"field-day-narrow": "日",
	"dateFormatItem-MMM": "LLL",
	"field-minute-short": "分",
	"field-dayperiod": "午前/午後",
	"field-sat-short-relative+0": "今週の土曜",
	"field-sat-short-relative+1": "来週の土曜",
	"dateFormat-medium": "U年MMMd日",
	"dateFormatItem-yyyyMMMM": "U年MMMM",
	"dateFormatItem-UMMM": "U年MMM",
	"dateFormatItem-EEEEd": "d日EEEE",
	"dateFormatItem-yyyyM": "U年M月",
	"field-second-narrow": "秒",
	"field-mon-relative+0": "今週の月曜日",
	"field-day-narrow-relative+-1": "昨日",
	"field-year-short": "年",
	"field-mon-relative+1": "来週の月曜日",
	"field-day-narrow-relative+-2": "一昨日",
	"months-format-narrow": [
		"正",
		"二",
		"三",
		"四",
		"五",
		"六",
		"七",
		"八",
		"九",
		"十",
		"十一",
		"十二"
	],
	"field-quarter-relative+-1": "前四半期",
	"dateFormatItem-yyyyMMMd": "U年MMMd日",
	"field-dayperiod-narrow": "午前/午後",
	"field-week-narrow-relative+-1": "先週",
	"field-dayOfYear": "年の通日",
	"field-sat-relative+-1": "先週の土曜日",
	"dateFormatItem-Md": "M/d",
	"field-hour": "時",
	"months-format-wide": [
		"正月",
		"二月",
		"三月",
		"四月",
		"五月",
		"六月",
		"七月",
		"八月",
		"九月",
		"十月",
		"十一月",
		"十二月"
	],
	"dateFormat-full": "U年MMMd日EEEE",
	"dateFormatItem-UMd": "U年M月d日",
	"field-month-relative+-1": "先月",
	"dateFormatItem-Hms": "H:mm:ss",
	"field-quarter-short": "四半期",
	"field-sat-narrow-relative+0": "今週の土曜",
	"field-fri-relative+0": "今週の金曜日",
	"field-sat-narrow-relative+1": "来週の土曜",
	"field-fri-relative+1": "来週の金曜日",
	"dateFormatItem-EBhm": "BK:mm (E)",
	"field-month-narrow-relative+0": "今月",
	"field-month-narrow-relative+1": "来月",
	"field-sun-short-relative+0": "今週の日曜",
	"field-sun-short-relative+1": "来週の日曜",
	"field-week-relative+-1": "先週",
	"field-quarter-short-relative+-1": "前四半期",
	"months-format-abbr": [
		"正月",
		"二月",
		"三月",
		"四月",
		"五月",
		"六月",
		"七月",
		"八月",
		"九月",
		"十月",
		"十一月",
		"十二月"
	],
	"field-quarter-relative+0": "今四半期",
	"field-minute-relative+0": "1 分以内",
	"field-quarter-relative+1": "翌四半期",
	"field-wed-short-relative+-1": "先週の水曜",
	"dateFormat-short": "U-M-d",
	"dateFormatItem-Bh": "BK時",
	"field-year-narrow-relative+-1": "昨年",
	"field-thu-short-relative+-1": "先週の木曜",
	"dateFormatItem-yyyyMMMEd": "U年MMMd日(E)",
	"field-mon-narrow-relative+-1": "先週の月曜",
	"dateFormatItem-MMMMd": "MMMMd日",
	"field-thu-narrow-relative+-1": "先週の木曜",
	"dateFormatItem-E": "ccc",
	"dateFormatItem-H": "H時",
	"field-weekOfMonth-short": "月の週番号",
	"field-tue-narrow-relative+-1": "先週の火曜",
	"dateFormatItem-yyyy": "U年",
	"dateFormatItem-M": "MMM",
	"months-standAlone-wide": [
		"正月",
		"二月",
		"三月",
		"四月",
		"五月",
		"六月",
		"七月",
		"八月",
		"九月",
		"十月",
		"十一月",
		"十二月"
	],
	"field-wed-short-relative+0": "今週の水曜",
	"field-wed-short-relative+1": "来週の水曜",
	"field-sun-relative+-1": "先週の日曜日",
	"dateFormatItem-hm": "aK:mm",
	"dateFormatItem-d": "d日",
	"field-weekday": "曜日",
	"field-day-short-relative+0": "今日",
	"field-quarter-narrow-relative+0": "今四半期",
	"field-day-short-relative+1": "明日",
	"field-sat-relative+0": "今週の土曜日",
	"field-quarter-narrow-relative+1": "翌四半期",
	"dateFormatItem-h": "aK時",
	"dateFormatItem-yyyyMEEEEd": "U年M月d日EEEE",
	"field-day-short-relative+2": "明後日",
	"field-sat-relative+1": "来週の土曜日",
	"field-week-short-relative+0": "今週",
	"field-week-short-relative+1": "来週",
	"months-standAlone-abbr": [
		"正月",
		"二月",
		"三月",
		"四月",
		"五月",
		"六月",
		"七月",
		"八月",
		"九月",
		"十月",
		"十一月",
		"十二月"
	],
	"field-dayOfYear-narrow": "通日",
	"field-month-short-relative+0": "今月",
	"field-month-short-relative+1": "来月",
	"field-weekdayOfMonth-short": "月の曜日番号",
	"dateFormatItem-MEd": "M/d(E)",
	"field-zone-narrow": "タイムゾーン",
	"dateFormatItem-y": "U年",
	"field-thu-narrow-relative+0": "今週の木曜",
	"field-sun-narrow-relative+-1": "先週の日曜",
	"field-mon-short-relative+-1": "先週の月曜",
	"field-thu-narrow-relative+1": "来週の木曜",
	"field-thu-relative+0": "今週の木曜日",
	"field-thu-relative+1": "来週の木曜日",
	"dateFormatItem-hms": "aK:mm:ss",
	"field-fri-short-relative+-1": "先週の金曜",
	"field-thu-relative+-1": "先週の木曜日",
	"dateFormatItem-yMd": "U年M月d日",
	"field-week": "週",
	"dateFormatItem-Ed": "d日(E)",
	"field-wed-narrow-relative+0": "今週の水曜",
	"field-wed-narrow-relative+1": "来週の水曜",
	"dateFormatItem-yyyyMMMEEEEd": "U年MMMd日EEEE",
	"field-quarter-narrow-relative+-1": "前四半期",
	"field-year-short-relative+0": "今年",
	"dateFormatItem-yyyyMMM": "U年MMM",
	"field-dayperiod-short": "午前/午後",
	"field-year-short-relative+1": "来年",
	"field-fri-short-relative+0": "今週の金曜",
	"field-fri-short-relative+1": "来週の金曜",
	"field-week-short-relative+-1": "先週",
	"dateFormatItem-yyyyQQQQ": "U年QQQQ",
	"dateFormatItem-UMMMd": "U年MMMd日",
	"field-hour-short": "時",
	"field-zone-short": "タイムゾーン",
	"field-month-narrow": "月",
	"field-hour-narrow": "時",
	"field-fri-narrow-relative+-1": "先週の金曜",
	"field-year-relative+0": "今年",
	"field-year-relative+1": "来年",
	"field-era-narrow": "時代",
	"field-fri-relative+-1": "先週の金曜日",
	"dateFormatItem-Bhms": "BK:mm:ss",
	"field-tue-short-relative+-1": "先週の火曜",
	"field-minute-narrow": "分",
	"field-mon-narrow-relative+0": "今週の月曜",
	"field-mon-narrow-relative+1": "来週の月曜",
	"dateFormatItem-GyMMMEEEEd": "U年MMMd日EEEE",
	"field-year-short-relative+-1": "昨年",
	"field-zone": "タイムゾーン",
	"dateFormatItem-MMMEd": "MMMd日(E)",
	"field-weekOfMonth-narrow": "月の週番号",
	"field-weekday-narrow": "曜日",
	"field-quarter-narrow": "四半期",
	"field-sun-short-relative+-1": "先週の日曜",
	"field-day-relative+-1": "昨日",
	"field-day-relative+-2": "一昨日",
	"field-weekday-short": "曜日",
	"dateFormatItem-Bhm": "BK:mm",
	"field-sun-relative+0": "今週の日曜日",
	"field-sun-relative+1": "来週の日曜日",
	"dateFormatItem-Gy": "U年",
	"field-day-short": "日",
	"field-week-narrow": "週",
	"field-era": "時代",
	"field-fri-narrow-relative+0": "今週の金曜",
	"dateFormatItem-UM": "U年M月",
	"field-fri-narrow-relative+1": "来週の金曜"
}
//end v1.x content
);
